uploads.UploadsByController (Upload files) — amici1

# `uploads.UploadsByController` (Upload files)

Columns

- `<django.db.models.fields.BigAutoField: id>`

- `<django.db.models.fields.related.ForeignKey: user>`

- `<django.db.models.fields.files.FileField: file>`

- `<django.db.models.fields.CharField: mimetype>`

- `<django.db.models.fields.IntegerField: file_size>`

- `<django.db.models.fields.related.ForeignKey: owner_type>`

- `<lino.modlib.gfks.fields.GenericForeignKeyIdField: owner_id>`

- `<lino.core.choicelists.ChoiceListField: upload_area>`

- `<django.db.models.fields.related.ForeignKey: type>`

- `<django.db.models.fields.related.ForeignKey: volume>`

- `<django.db.models.fields.CharField: library_file>`

- `<django.db.models.fields.CharField: description>`

- `<lino.modlib.gfks.fields.GenericForeignKey object at 0x7fc822220dd8>`

Detail fields

- `<Panel main_1 in lino.core.layouts.DetailLayout on lino.modlib.uploads.models.Uploads>`

- `<Panel main_2 in lino.core.layouts.DetailLayout on lino.modlib.uploads.models.Uploads>`

- `<Panel main_3 in lino.core.layouts.DetailLayout on lino.modlib.uploads.models.Uploads>`

- Controlled by (owner) : See `<lino.modlib.gfks.fields.GenericForeignKey object at 0x7fc822220dd8>`.

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Export to .xls (export_excel) : Export this table as an .xls document

- None (grid_post) : See `<lino.core.actions.CreateRow grid_post>`.

- None (grid_put) : See `<lino.core.actions.SaveGridCell grid_put>`.

- New (insert) : Open a dialog window to insert a new Upload file.

- Create (submit_insert) : Create the record and open a detail window on it

- Detail (detail) : Open a detail window on this record.

- Delete (delete_selected) : Delete this record

- Check data (check_data) : See `<lino.modlib.checkdata.models.UpdateProblemsByController check_data ('Check data')>`.

- Fix data problems (fix_problems) : See `<lino.modlib.checkdata.models.FixProblemsByController fix_problems ('Fix data problems')>`.

- None (grid) : See `<lino.core.actions.ShowTable grid>`.

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

- None (validate) : See `<lino.core.actions.ValidateForm validate>`.

- Save (submit_detail) : Save changes in this form

Filter parameters

- `<django.db.models.fields.related.ForeignKey: upload_type>`

- `<django.db.models.fields.DateField: start_date>`

- `<django.db.models.fields.DateField: end_date>`

- `<django.db.models.fields.related.ForeignKey: user>`

## Filter parameters